using AipGateway.AIP;
using AipGateway.API.Domain.Models.Request;
using AipGateway.API.Domain.Models.Response;

namespace AipGateway.API.Services
{
    public interface IApiStreamService
    {
        Task<ResponseInfo> GetInfo(RequestStream req);
        Task<ResponseStream> SetLabel(RequestStreamSet req);
        Task<ResponseStream> DelLabel(RequestStreamDel req);
        Task<ResponseStream> SetProtection(RequestStreamSet req);
        Task<ResponseStream> DelProtection(RequestStreamDel req);
        Task<ResponseStream> SetLabelProtection(RequestStreamAllSet req);
        Task<ResponseStream> DelLabelProtection(RequestStreamDel req);
    }
}
